==> MacOSX10.11.sdk.zip: MacOSX10.11.sdk/System/Library/Frameworks/Quartz.framework/Versions/A/Frameworks/PDFKit.framework/Versions/A/Headers/PDFAnnotationChoiceWidget.h <==
// =====================================================================================================================
//  PDFAnnotationChoiceWidget.h
// =====================================================================================================================


#import <AppKit/AppKit.h>
#import <PDFKit/PDFAnnotation.h>


#if MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_5

@class PDFAnnotationChoiceWidgetPrivateVars;


@interface PDFAnnotationChoiceWidget : PDFAnnotation <NSCopying>
{
@private
    PDFAnnotationChoiceWidgetPrivateVars *_pdfPriv2;
}

// -------- accessors

// The string value associated with the widget.
- (NSString *) stringValue;
- (void) setStringValue: (NSString *) value;

// Background color characteristics.
- (NSColor *) backgroundColor;
- (void) setBackgroundColor: (NSColor *) color;

// Font characteristics.
- (NSFont *) font;
- (void) setFont: (NSFont *) font;

// Font color characteristics.
- (NSColor *) fontColor;
- (void) setFontColor: (NSColor *) color;

// Widget annotations backed by form data have (internal) field names with which to associate a value or data.
- (NSString *) fieldName;
- (void) setFieldName: (NSString *) name;

// There are two flavors of Choice widget annotations, lists and pop-up menus. These methods allow you to differentiate.
- (BOOL) isListChoice;
- (void) setIsListChoice: (BOOL) isList;

// The choices are an array of strings indicating the options (items) in either a list or pop-up menu.
- (NSArray *) choices;
- (void) setChoices: (NSArray *) options;

@end

#endif	// MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_5

==> MacOSX10.12.sdk.zip: MacOSX10.12.sdk/System/Library/Frameworks/Quartz.framework/Versions/A/Frameworks/PDFKit.framework/Versions/A/Headers/PDFAnnotationChoiceWidget.h <==
// =====================================================================================================================
//  PDFAnnotationChoiceWidget.h
// =====================================================================================================================


#import <PDFKit/PDFKitPlatform.h>

#import <PDFKit/PDFAnnotation.h>

@class PDFAnnotationChoiceWidgetPrivateVars;

NS_CLASS_DEPRECATED_MAC(10_5, 10_12, "Use the PDFAnnotation class directly, setting properties via kPDFAnnotationKey_* keys using method [setValue:forAnnotationKey:]")
@interface PDFAnnotationChoiceWidget : PDFAnnotation <NSCopying>
{
@private
    PDFAnnotationChoiceWidgetPrivateVars *_private2;
}

// -------- accessors

// The string value associated with the widget.
- (NSString *) stringValue;
- (void) setStringValue: (NSString *) value;

// Background color characteristics.
- (PDFKitPlatformColor *) backgroundColor;
- (void) setBackgroundColor: (PDFKitPlatformColor *) color;

// Font characteristics.
- (PDFKitPlatformFont *) font;
- (void) setFont: (PDFKitPlatformFont *) font;

// Font color characteristics.
- (PDFKitPlatformColor *) fontColor;
- (void) setFontColor: (PDFKitPlatformColor *) color;

// Widget annotations backed by form data have (internal) field names with which to associate a value or data.
- (NSString *) fieldName;
- (void) setFieldName: (NSString *) name;

// There are two flavors of Choice widget annotations, lists and pop-up menus. These methods allow you to differentiate.
- (BOOL) isListChoice;
- (void) setIsListChoice: (BOOL) isList;

// The choices are an array of strings indicating the options (items) in either a list or pop-up menu.
- (NSArray *) choices;
- (void) setChoices: (NSArray *) options;

@end
